StarterKitUiConfig class

UI behavior controls for global StarterKit widgets.

Constructors

StarterKitUiConfig({bool showConnectivityBanner = true, bool showForceUpdateScreen = true, bool showMaintenanceScreen = true, bool enableGlobalLoader = true, bool enableDevPanel = true, DevPanelTrigger devPanelTrigger = DevPanelTrigger.floatingButton})
const
StarterKitUiConfig.defaults()
factory

Properties

devPanelTrigger → DevPanelTrigger
Trigger used to open the Dev Panel in debug builds.
final
enableDevPanel → bool
Enables the in-app Dev Panel (only active when kDebugMode is true).
final
enableGlobalLoader → bool
Enables usage of global loader overlay in app wrapper.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showConnectivityBanner → bool
Automatically show connectivity banner when disconnected.
final
showForceUpdateScreen → bool
Automatically show force update full-screen gate.
final
showMaintenanceScreen → bool
Automatically show maintenance full-screen gate.
final

Methods

copyWith({bool? showConnectivityBanner, bool? showForceUpdateScreen, bool? showMaintenanceScreen, bool? enableGlobalLoader, bool? enableDevPanel, DevPanelTrigger? devPanelTrigger}) → StarterKitUiConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited