StorageError class final

Storage-related errors.

Inheritance

Constructors

StorageError({required String message, String? code, Object? originalError, StackTrace? stackTrace})
const
StorageError.deleteFailed(String key)
factory
StorageError.notFound(String key)
factory
StorageError.readFailed(String key)
factory
StorageError.writeFailed(String key)
factory

Properties

code → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
originalError → Object?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited