StringExtensions extension

Extension methods for String.

on

Properties

isBlank → bool

Available on String, provided by the StringExtensions extension

Checks if the string is empty or contains only whitespace.
no setter
isNotBlank → bool

Available on String, provided by the StringExtensions extension

Checks if the string is not empty and not blank.
no setter
isValidEmail → bool

Available on String, provided by the StringExtensions extension

Checks if the string is a valid email address.
no setter

Methods

capitalize() → String

Available on String, provided by the StringExtensions extension

Capitalizes the first letter of the string.
capitalizeWords() → String

Available on String, provided by the StringExtensions extension

Capitalizes the first letter of each word.