UpdateStatus enum
Update status enum.
Values
- upToDate → const UpdateStatus
-
App is up to date.
- updateAvailable → const UpdateStatus
-
Update is available but not required.
- forceUpdateRequired → const UpdateStatus
-
Force update is required.
- maintenanceMode → const UpdateStatus
-
App is in maintenance mode.
- unknown → const UpdateStatus
-
Status is unknown or check failed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UpdateStatus> - A constant List of the values in this enum, in order of their declaration.