ValidationError class final
Validation errors.
Constructors
- ValidationError({required String message, String? code, Object? originalError, StackTrace? stackTrace})
-
const
- ValidationError.invalidEmail()
-
factory
- ValidationError.maxLength(String field, int max)
-
factory
- ValidationError.minLength(String field, int min)
-
factory
- ValidationError.required(String field)
-
factory
Properties
- code → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- originalError → Object?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited