IConnectivityService class abstract
Interface for connectivity monitoring service.
Constructors
Properties
-
connectionStream
→ Stream<
NetworkConnectionState> -
Stream of connection state changes.
no setter
- currentState → NetworkConnectionState
-
Current connection state.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkConnection(
) → Future< NetworkConnectionState> - Checks the current connection state.
-
dispose(
) → void - Disposes the service and cancels subscriptions.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited